#!/bin/sh

. /etc/PG.conf

self_pid=$$
RAMDISK=/usr/ramdisk
LOGDIR=${RAMDISK}/tmp
APPNAME=hasync
APPROOT=${RAMDISK}/app/${APPNAME}
APPCONF=${APPROOT}/conf
APPBIN=${APPROOT}/bin

standby=/etc/standby
filelog=${LOGDIR}/filelog.log
actlog=${LOGDIR}/actlog.log
webconf=${PGETC}/hasync.conf
rsyncd=${APPCONF}/rsyncd.conf

RSYNC=${APPBIN}/rsync
RSYNC_CLIENT=${APPBIN}/rsync_client
IPECTRL=${RAMDISK}/bin/ipectrl
FLOWEYE=${RAMDISK}/bin/floweye

stop_panaos()
{
        sleep .1
        errmsg=`${IPECTRL} stop panaos`
        sleep .1
        errmsg=`${IPECTRL} stop panaos`

        # Waiting panaos exit
        count=50
        while [ ${count} -gt 0 ]; do
                panaos=`ps ax | awk '{print $5}' | grep panaos`
                [ "${panaos}" = "" ] && break
                sleep .2
                count=$((${count} - 1))
        done
}

start_panaos()
{
        local cnt=30

	${IPECTRL} start panaos
        
        while [ ${cnt} -gt 0 ]; do
                err=`/usr/ramdisk/bin/floweye system stat`
                [ "$?" = "0" ] && return 0
                sleep 1
                cnt=$((${cnt} - 1))
        done
                                
        return 1
}

recode_pxymac()
{
	[ -f ${pxymac} ] && rm ${pxymac}
	for lid in `floweye nat listproxy | grep rtif | cut -d" " -f2`
	do
        	ifmac=`floweye nat getproxy  ${lid} | grep ifmac | cut -d"=" -f2`
        	name=`floweye nat getproxy ${lid} | grep ^name | cut -d"=" -f2`
        	echo "$name=$ifmac" >> ${pxymac}
	done
}

set_rsyncd()
{
	sed -e "s/ALLOWIP/${allowip}/g" ${APPCONF}/rsyncd.temp > ${APPCONF}/rsyncd.conf
}

set_exclude()
{
	cp ${APPCONF}/exclude.temp ${APPCONF}/exclude.conf
	[ ${expaconf} -eq 0 ] && echo "panabit.conf" >> ${APPCONF}/exclude.conf
}

#stop process first
[ -f  /var/run/rsyncd.pid ] && rm  /var/run/rsyncd.pid
rsync_pid=`ps -ax | grep rsync | awk '{print $1}'`        
backping_pid=`ps -ax | grep ha_monitor | awk '{print $1}'`

if [ "${backping_pid}" != "" ]; then
	for pid in ${backping_pid}; do
		kill -9 $pid
	done
fi
if [ "${rsync_pid}" != "" ]; then
	for pid in ${rsync_pid}; do
		[ ${pid} -eq ${self_pid} ] && continue
		kill -9 $pid
	done 
fi

#set mode second
. ${webconf}
if [ ${mode} == "along_mode" ]; then
	stop_panaos
	[ -f ${standby} ] && rm ${standby}
	start_panaos

elif [ ${mode} == "active_mode" ]; then
	stop_panaos
	[ -f ${standby} ] && rm ${standby}
	start_panaos
	${FLOWEYE} nat addrtif name=_HAPING_ ifname=${halan_if} addr=${halan_ip} netmask=${halan_mask} vlan=${halan_vlan}

	set_rsyncd
	${RSYNC} --config=${rsyncd} --daemon

elif [ ${mode} == "backup_mode" ]; then
	stop_panaos
        [ ! -f ${standby} ] && touch ${standby}
        start_panaos
        ${FLOWEYE} nat addrtif name=_HAPING_ ifname=${halan_if} addr=${halan_ip} netmask=${halan_mask} vlan=${halan_vlan}
	
	#first, start rsync_client
	#second, in script rsync_client , start ha_monitor
	#because before start ha_monitor, must rsync file ok!
	set_exclude
        ${RSYNC_CLIENT} ${mgtip} ${slptime} &
fi
